class A {
public:
   int f () { ; }
   int g () { ; }
   int h ();
};

